==> nm-tray_0.3.0.orig.tar.gz: nm-tray-0.3.0/translations/nm-tray_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informacje o połączeniu</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="14"/>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="20"/>
        <source>All information</source>
        <translation>Wszystkie informacje</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="30"/>
        <source>Active connections</source>
        <translation>Aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="40"/>
        <source>Available wireless</source>
        <translation>Dostępne połączenia bezprzewodowe</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="792"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="794"/>
        <source>active connection(s)</source>
        <translation>aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="796"/>
        <source>connection(s)</source>
        <translation>połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="798"/>
        <source>device(s)</source>
        <translation>urządzenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="800"/>
        <source>wifi network(s)</source>
        <translation>sieci bezprzewodowe</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1030"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>nieznany</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - hasło połączenia bezprzewodowego</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Potrzebne jest hasło, aby połączyć się z &apos;%1&apos;:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1133"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1134"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1136"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adres urządzenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1138"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Informacje o aktywnym połączeniu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1140"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1142"/>
        <source> Kb/s</source>
        <translation>Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1144"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>nieznana</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1148"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1164"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adres IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1166"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Maska podsieci</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1175"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Brama domyślna</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="190"/>
        <source>Connection lost</source>
        <translation>Utracono połączenie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="191"/>
        <source>We have just lost the connection to %1 &apos;%2&apos;.</source>
        <translation>Utracono połączenie z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>Connection established</source>
        <translation>Ustanowiono połączenie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="204"/>
        <source>We have just established the connection to %1 &apos;%2&apos;.</source>
        <translation>Ustanowiono połączenie z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="208"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager(nm-tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="241"/>
        <source>Enable Networking</source>
        <translation>Włącz sieci</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="242"/>
        <source>Enable Wi-fi</source>
        <translation>Włącz Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="244"/>
        <source>Enable notifications</source>
        <translation>Włącz powiadomienia</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="246"/>
        <source>Connection information</source>
        <translation>Informacje o połączeniu</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="247"/>
        <source>Debug information</source>
        <translation>Informacje debugowania</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="249"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="251"/>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="335"/>
        <source>%1 about</source>
        <translation>o %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="336"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; jest prostą, napisaną w Qt nakładką dla &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManagera&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Wersja: %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="276"/>
        <source>nm-tray info</source>
        <translation>Informacje o nm-tray</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="133"/>
        <source>Active connection(s)</source>
        <translation>Aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="136"/>
        <source>Wi-Fi network(s)</source>
        <translation>Sieci Wi-Fi</translation>
    </message>
</context>
</TS>

==> nm-tray_0.4.1.orig.tar.gz: nm-tray-0.4.1/translations/nm-tray_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informacje o połączeniu</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="14"/>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="20"/>
        <source>All information</source>
        <translation>Wszystkie informacje</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="30"/>
        <source>Active connections</source>
        <translation>Aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="40"/>
        <source>Available wireless</source>
        <translation>Dostępne połączenia bezprzewodowe</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="728"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="730"/>
        <source>active connection(s)</source>
        <translation>aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="732"/>
        <source>connection(s)</source>
        <translation>połączenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="734"/>
        <source>device(s)</source>
        <translation>urządzenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="736"/>
        <source>wifi network(s)</source>
        <translation>sieci bezprzewodowe</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1027"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>nieznany</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - hasło połączenia bezprzewodowego</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Potrzebne jest hasło, aby połączyć się z &apos;%1&apos;:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1130"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1131"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1133"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adres urządzenia</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1135"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Informacje o aktywnym połączeniu</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1137"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1139"/>
        <source> Kb/s</source>
        <translation> Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1141"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>nieznana</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1145"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1149"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1150"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1161"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adres IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Maska podsieci</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Brama domyślna</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1178"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Utracono połączenie</translation>
    </message>
    <message>
        <source>We have just lost the connection to %1 &apos;%2&apos;.</source>
        <translation type="vanished">Utracono połączenie z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Ustanowiono połączenie</translation>
    </message>
    <message>
        <source>We have just established the connection to %1 &apos;%2&apos;.</source>
        <translation type="vanished">Ustanowiono połączenie z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager(nm-tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Włącz sieci</translation>
    </message>
    <message>
        <source>Enable Wi-fi</source>
        <translation type="vanished">Włącz Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Połączenie &lt;strong&gt;%1&lt;/strong&gt;(%2) aktywne&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Brak aktywnego połączenia&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Rozłączono z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Jesteś teraz połączony z %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Włącz Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Włącz powiadomienia</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informacje o połączeniu</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Informacje debugowania</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Edit connections...</source>
        <translation>Edytuj połączenia…</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="263"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="265"/>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="382"/>
        <source>%1 about</source>
        <translation>o %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="383"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; jest prostą, napisaną w Qt nakładką dla &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManagera&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Wersja: %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="290"/>
        <source>nm-tray info</source>
        <translation>Informacje o nm-tray</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktywne połączenia</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Sieci Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Znane połączenia</translation>
    </message>
</context>
</TS>
